
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.9',
    'branch_nick': 'patch-0-Release__1_23_9_preparation',
    'revision_id': '7ec4759fa82646128b4495e4786465331662b00e',
    'revno': 10173
}
